summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/macros/lib/variable.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/macros/lib/variable.h')
-rw-r--r--kexi/plugins/macros/lib/variable.h86
1 files changed, 43 insertions, 43 deletions
diff --git a/kexi/plugins/macros/lib/variable.h b/kexi/plugins/macros/lib/variable.h
index 26e9619ee..108a6005e 100644
--- a/kexi/plugins/macros/lib/variable.h
+++ b/kexi/plugins/macros/lib/variable.h
@@ -20,9 +20,9 @@
#ifndef KOMACRO_VARIABLE_H
#define KOMACRO_VARIABLE_H
-#include <qobject.h>
-#include <qdom.h>
-#include <qvariant.h>
+#include <tqobject.h>
+#include <tqdom.h>
+#include <tqvariant.h>
#include <ksharedptr.h>
#include "metaparameter.h"
@@ -31,7 +31,7 @@ namespace KoMacro {
/**
* A variable value used to provide abstract access to variables. The
* class handles QVariant and QObject and provides access to them.
* Variable inherits KShared and implements reference couting. So, it's
* not needed to take care of memory-managment.
*/
@@ -39,31 +39,31 @@ namespace KoMacro {
{
/**
* Property to get and set a QVariant as variable.
*/
- Q_PROPERTY(QVariant variant READ variant WRITE setVariant)
+ TQ_PROPERTY(TQVariant variant READ variant WRITE setVariant)
/**
* Property to get and set a QObject as variable.
*/
- Q_PROPERTY(QObject* object READ object WRITE setObject)
+ TQ_PROPERTY(TQObject* object READ object WRITE setObject)
/**
* Property to get a string-representation of the variable.
*/
- Q_PROPERTY(QString string READ toString)
+ TQ_PROPERTY(TQString string READ toString)
public:
/**
* A list of variables.
*/
- typedef QValueList<KSharedPtr<Variable > > List;
+ typedef TQValueList<KSharedPtr<Variable > > List;
/**
* A map of variables.
*/
- typedef QMap<QString, KSharedPtr<Variable > > Map;
+ typedef TQMap<TQString, KSharedPtr<Variable > > Map;
/**
* Default constructor.
@@ -71,28 +71,28 @@ namespace KoMacro {
explicit Variable();
/**
* Constructor from the QVariant @p variant .
*
* @param variant The value this variable has.
* @param name The unique @a name() this variable has.
* @param text The describing @a text() this variable has.
*/
- Variable(const QVariant& variant, const QString& name = QString::null, const QString& text = QString::null);
+ Variable(const TQVariant& variant, const TQString& name = TQString(), const TQString& text = TQString());
/**
* Constructor from the QObject @p object .
*
* @param object The value this variable has.
*/
- Variable(const QObject* object);
+ Variable(const TQObject* object);
/**
* Constructor from the QDomElement @p element .
* @deprecated replaced with methods of @a XMLHandler.
* @param element The QDomElement that may optional contains the
* variable content or other additional informations.
*/
- Variable(const QDomElement& element);
+ Variable(const TQDomElement& element);
/**
* Destructor.
@@ -102,69 +102,69 @@ namespace KoMacro {
/**
* @return the name this @a Variable has.
*/
- QString name() const;
+ TQString name() const;
/**
* Set the name @param name this @a Variable has.
*/
- void setName(const QString& name);
+ void setName(const TQString& name);
/**
* @return the caption this @a Variable has.
*/
- QString text() const;
+ TQString text() const;
/**
* Set the caption @param text this @a Variable has.
*/
- void setText(const QString& text);
+ void setText(const TQString& text);
/**
* Set the QObject @param object this variable has. A
* previously remembered value will be overwritten and
* the new type is a @a TypeObject .
*/
- void setObject(const QObject* object);
+ void setObject(const TQObject* object);
/**
* @return the QVariant this variable has. If this
* variable isn't a @a TypeVariant an invalid QVariant
* got returned.
*/
- const QVariant variant() const;
+ const TQVariant variant() const;
/**
* Set the QVariant @param variant this variable has. A
* previously remembered value will be overwritten and
* the new type is a @a TypeVariant . If @param detecttype is
* true the method tries to set the @a variantType according
* to the passed QVariant. If false the variantType won't
* be changed.
*/
- void setVariant(const QVariant& variant, bool detecttype = true);
+ void setVariant(const TQVariant& variant, bool detecttype = true);
/**
* @return the QObject this variable has. If this
* variable isn't a @a TypeObject NULL got returned.
*/
- const QObject* object() const;
+ const TQObject* object() const;
/**
* Implicit conversion to QVariant operator. This method
* calls @a variant() internaly.
*/
- operator QVariant () const;
+ operator TQVariant () const;
/**
* Implicit conversion to QObject operator. This method
* calls @a object() internaly.
*/
- operator const QObject* () const;
+ operator const TQObject* () const;
/**
* @return a string-represenation of the variable.
*/
- const QString toString() const;
+ const TQString toString() const;
/**
* @return a integer-represenation of the variable.
@@ -173,29 +173,29 @@ namespace KoMacro {
/**
* @return the optional list of @a Variable instances
* that are children of this @a Variable .
*
* @note that the list is returned call-by-reference. The
* list is accessed as getter/setter (read/write). So,
* don't set this method to const!
*/
- List children() const;
+ List tqchildren() const;
/**
* Append a @a Variable to the list of children this
* @a Variable has.
*/
void appendChild(KSharedPtr<Variable> variable);
/**
* Clear the list of children this @a Variable has.
*/
void clearChildren();
/**
* Set the children this @a Variable has.
*/
- void setChildren(const List& children);
+ void setChildren(const List& tqchildren);
#if 0
/**
@@ -31,7 +31,7 @@ namespace KoMacro {
/**
* A variable value used to provide abstract access to variables. The
- * class handles QVariant and QObject and provides access to them.
+ * class handles TQVariant and TQObject and provides access to them.
* Variable inherits KShared and implements reference couting. So, it's
* not needed to take care of memory-managment.
@@ -39,31 +39,31 @@ namespace KoMacro {
{
/**
- * Property to get and set a QVariant as variable.
+ * Property to get and set a TQVariant as variable.
*/
@@ -39,31 +39,31 @@ namespace KoMacro {
/**
- * Property to get and set a QObject as variable.
+ * Property to get and set a TQObject as variable.
*/
@@ -71,28 +71,28 @@ namespace KoMacro {
explicit Variable();
/**
- * Constructor from the QVariant @p variant .
+ * Constructor from the TQVariant @p variant .
*
* @param variant The value this variable has.
@@ -71,28 +71,28 @@ namespace KoMacro {
/**
- * Constructor from the QObject @p object .
+ * Constructor from the TQObject @p object .
*
* @param object The value this variable has.
@@ -71,28 +71,28 @@ namespace KoMacro {
/**
- * Constructor from the QDomElement @p element .
+ * Constructor from the TQDomElement @p element .
* @deprecated replaced with methods of @a XMLHandler.
@@ -71,28 +71,28 @@ namespace KoMacro {
* @deprecated replaced with methods of @a XMLHandler.
- * @param element The QDomElement that may optional contains the
+ * @param element The TQDomElement that may optional contains the
* variable content or other additional informations.
*/
@@ -102,69 +102,69 @@ namespace KoMacro {
/**
- * Set the QObject @param object this variable has. A
+ * Set the TQObject @param object this variable has. A
* previously remembered value will be overwritten and
* the new type is a @a TypeObject .
@@ -102,69 +102,69 @@ namespace KoMacro {
/**
- * @return the QVariant this variable has. If this
- * variable isn't a @a TypeVariant an invalid QVariant
+ * @return the TQVariant this variable has. If this
+ * variable isn't a @a TypeVariant an invalid TQVariant
* got returned.
*/
@@ -102,69 +102,69 @@ namespace KoMacro {
/**
- * Set the QVariant @param variant this variable has. A
+ * Set the TQVariant @param variant this variable has. A
* previously remembered value will be overwritten and
* the new type is a @a TypeVariant . If @param detecttype is
@@ -102,69 +102,69 @@ namespace KoMacro {
* the new type is a @a TypeVariant . If @param detecttype is
* true the method tries to set the @a variantType according
- * to the passed QVariant. If false the variantType won't
+ * to the passed TQVariant. If false the variantType won't
* be changed.
*/
@@ -102,69 +102,69 @@ namespace KoMacro {
/**
- * @return the QObject this variable has. If this
+ * @return the TQObject this variable has. If this
* variable isn't a @a TypeObject NULL got returned.
*/
@@ -102,69 +102,69 @@ namespace KoMacro {
/**
- * Implicit conversion to QVariant operator. This method
+ * Implicit conversion to TQVariant operator. This method
* calls @a variant() internaly.
*/
@@ -102,69 +102,69 @@ namespace KoMacro {
/**
- * Implicit conversion to QObject operator. This method
+ * Implicit conversion to TQObject operator. This method
* calls @a object() internaly.
*/
@@ -173,29 +173,29 @@ namespace KoMacro {
/**
* @return the optional list of @a Variable instances
- * that are children of this @a Variable .
+ * that are tqchildren of this @a Variable .
*
* @note that the list is returned call-by-reference. The
@@ -173,29 +173,29 @@ namespace KoMacro {
/**
- * Append a @a Variable to the list of children this
+ * Append a @a Variable to the list of tqchildren this
* @a Variable has.
*/
@@ -173,29 +173,29 @@ namespace KoMacro {
void appendChild(KSharedPtr<Variable> variable);
/**
- * Clear the list of children this @a Variable has.
+ * Clear the list of tqchildren this @a Variable has.
*/
void clearChildren();
@@ -173,29 +173,29 @@ namespace KoMacro {
void clearChildren();
/**
- * Set the children this @a Variable has.
+ * Set the tqchildren this @a Variable has.
*/